<?php

/**
 * @file
 * Module Settings
 */

/**
 * Core settings function
 */
function udheader_admin_settings() {
  $tid = intval(arg(4));
  if ($tid > 0) {
    $edit = db_query('SELECT * FROM {udheader} WHERE tid = :tid', array(':tid' => $tid));
    $form = drupal_get_form('udheader_linkform', $edit->fetchAssoc(), TRUE);
  } else {
    $form = drupal_get_form('udheader_linkform', array(), FALSE);
    $form['header_maps'] = array(
      '#type' => 'item',
      '#title' => t('Header Maps'),
      '#markup' => udheader_view_list(),
    );
  }
  return $form;
}

/**
 * Build form to add/edit location links
 */
function udheader_linkform($form, &$form_state, $edit = array(), $individual = FALSE) {
  // Get available node types
  $node_types = node_type_get_names();
  $node_types['udheader_default'] = 'Default';

  // Get left images
  $dir =  drupal_get_path('module', 'udheader') . "/images/left/";
  $handle = opendir($dir);
  while (false !== ($file = readdir($handle))) {
    if ($file != '.' && $file != '..') {
      $images['left'][$file] = $file;
    }
  }
  closedir($handle);

  // Get center images
  $dir =  drupal_get_path('module', 'udheader') . "/images/center/";
  $handle = opendir($dir);
  while (false !== ($file = readdir($handle))) {
    if ($file != '.' && $file != '..') {
      $images['center'][$file] = $file;
    }
  }
  closedir($handle);

  // Get right images
  $dir =  drupal_get_path('module', 'udheader') . "/images/right/";
  $handle = opendir($dir);
  while (false !== ($file = readdir($handle))) {
    if ($file != '.' && $file != '..') {
      $images['right'][$file] = $file;
    }
  }
  closedir($handle);

  $form = array();

  $c = isset($edit['tid']) && $edit['tid'] > 0 ? FALSE : TRUE;
  $t = isset($edit['tid']) && $edit['tid'] > 0 ? 'Edit' : 'Add';

  $form['udheader'] = array(
    '#type' => 'fieldset',
    '#title' => t($t . ' Header'),
    '#collapsible' => $c,
    '#collapsed' => $c,
    '#tree' => FALSE,
  );
  $form['udheader']['tid'] = array(
    '#type' => 'hidden',
    '#value' => isset($edit['tid']) ? $edit['tid'] : '',
  );
  $form['udheader']['node'] = array(
    '#type' => 'select',
    '#title' => t('Node Type'),
    '#options' => $node_types,
    '#default_value' => isset($edit['node']) ? t($edit['node']) : '',
    '#description' => t('Select the node type which the header will be applied for.'),
  );
  $form['udheader']['left'] = array(
    '#type' => 'select',
    '#title' => t('Left Image'),
    '#options' => $images['left'],
    '#default_value' => isset($edit['leftimg']) ? t($edit['leftimg']) : '',
    '#description' => t('Select the image to be used on the left side of the header.'),
  );
  $form['udheader']['center'] = array(
    '#type' => 'select',
    '#title' => t('Center Image'),
    '#options' => $images['center'],
    '#default_value' => isset($edit['centerimg']) ? t($edit['centerimg']) : '',
    '#description' => t('Select the image to be used in the center of the header.'),
  );
  $form['udheader']['centertext'] = array(
    '#type' => 'textarea',
    '#title' => t('Text to be displayed in the center of the masthead'),
    '#default_value' => isset($edit['centertext']) ? t($edit['centertext']) : '',
  );
  $form['udheader']['right'] = array(
    '#type' => 'select',
    '#title' => t('Right Image'),
    '#options' => $images['right'],
    '#default_value' => isset($edit['rightimg']) ? t($edit['rightimg']) : '',
    '#description' => t('Select the image to be used on the right side of the header.'),
  );
  $form['udheader']['righttext'] = array(
    '#type' => 'textarea',
    '#title' => t('Text to be displayed in the right part of the masthead'),
    '#default_value' => isset($edit['righttext']) ? t($edit['righttext']) : '',
  );
  $form['udheader']['submit'] = array(
    '#type' => 'submit',
    '#value' => isset($edit['tid']) && $edit['tid'] > 0 ? 'Update' : 'Add'
  );

  if ($individual) {
    $form['udheader']['delete'] = array(
      '#type' => 'submit',
      '#value' => 'Delete',
    );
  }

  return $form;
}

/**
 * Build list of existing linked locations
 */
function udheader_view_list() {
  $imgmaps = db_query('SELECT * FROM {udheader}');
  $rows = array();
  $headers = array('Node Type', 'Left Image', 'Center Image', 'Right Image', 'Edit');

  foreach ($imgmaps as $imgmap) {
    $tid = strval($imgmap->tid);
    array_push($rows, array(
      t($imgmap->node),
      t($imgmap->leftimg),
      t($imgmap->centerimg),
      t($imgmap->rightimg),
      l(t('edit'), 'admin/config/content/udheader/'. $tid),
    ));
  }
  return theme('table', array('header' => $headers, 'rows' => $rows));
}

/**
 * Add/Delete/Update location link to database
 */
function udheader_linkform_submit($form, &$form_state) {

  $form_state['redirect'] = 'admin/config/content/udheader';

  $op         = $form_state['values']['op'];
  $tid        = $form_state['values']['tid'];
  $node       = $form_state['values']['node'];
  $left       = $form_state['values']['left'];
  $center     = $form_state['values']['center'];
  $centertext = $form_state['values']['centertext'];
  $right      = $form_state['values']['right'];
  $righttext  = $form_state['values']['righttext'];

  switch ($op) {
    case 'Update':
      // Update
      db_update('udheader')
        ->fields(array(
          'node'       => $node,
          'leftimg'    => $left,
          'centerimg'  => $center,
          'centertext' => $centertext,
          'rightimg'   => $right,
          'righttext'  => $righttext,
        ))
        ->condition('tid', $tid)
        ->execute();
      break;

    case 'Delete':
      // Delete
      db_delete('udheader')
        ->condition('tid', $tid)
        ->execute();
      break;

    case 'Add':
    default:
      // Add
      db_insert('udheader')
        -> fields(array(
          'node' => $node,
          'leftimg' => $left,
          'centerimg' => $center,
          'centertext' => $centertext,
          'rightimg' => $right,
          'righttext' => $righttext
        ))
        ->execute();
  }
}
